@@ -11,8 +11,6 @@
 # ANY KIND, either express or implied. See the License for the specific
 # language governing permissions and limitations under the License.
 import logging
-import os
-import warnings
 
 from botocore import waiter, xform_name
 from botocore.args import ClientArgsCreator
@@ -25,14 +23,11 @@ from botocore.discovery import (
     block_endpoint_discovery_required_operations,
 )
 from botocore.docs.docstring import ClientMethodDocstring, PaginatorDocstring
-from botocore.endpoint_provider import (
-    ENDPOINT_RESOLUTION_V2_SERVICES,
-    FORCE_ENDPOINT_RESOLUTION_V2,
-)
 from botocore.exceptions import (
     DataNotFoundError,
     InvalidEndpointDiscoveryConfigurationError,
     OperationNotPageableError,
+    UnknownServiceError,
     UnknownSignatureVersionError,
 )
 from botocore.history import get_global_history_recorder
@@ -66,6 +61,18 @@ from botocore.utils import S3RegionRedirector  # noqa
 from botocore import UNSIGNED  # noqa
 
 
+_LEGACY_SIGNATURE_VERSIONS = frozenset(
+    (
+        'v2',
+        'v3',
+        'v3https',
+        'v4',
+        's3',
+        's3v4',
+    )
+)
+
+
 logger = logging.getLogger(__name__)
 history_recorder = get_global_history_recorder()
 
@@ -117,18 +124,19 @@ class ClientCreator:
         )
         service_name = first_non_none_response(responses, default=service_name)
         service_model = self._load_service_model(service_name, api_version)
-
-        if (
-            service_name in ENDPOINT_RESOLUTION_V2_SERVICES
-            or FORCE_ENDPOINT_RESOLUTION_V2
-        ):
+        try:
             endpoints_ruleset_data = self._load_service_endpoints_ruleset(
                 service_name, api_version
             )
             partition_data = self._loader.load_data('partitions')
-        else:
+        except UnknownServiceError:
             endpoints_ruleset_data = None
             partition_data = None
+            logger.info(
+                'No endpoints ruleset found for service %s, falling back to '
+                'legacy endpoint routing.',
+                service_name,
+            )
 
         cls = self._create_client_class(service_name, service_model)
         region_name, client_config = self._normalize_fips_region(
@@ -140,6 +148,9 @@ class ClientCreator:
             client_config,
             service_signing_name=service_model.metadata.get('signingName'),
             config_store=self._config_store,
+            service_signature_version=service_model.metadata.get(
+                'signatureVersion'
+            ),
         )
         client_args = self._get_client_args(
             service_model,
@@ -157,16 +168,14 @@ class ClientCreator:
         )
         service_client = cls(**client_args)
         self._register_retries(service_client)
-        self._register_s3_events(service_client, client_config, scoped_config)
-        self._register_s3_control_events(service_client)
-
-        if client_args['endpoint_ruleset_resolver'] is None:
-            # When using the legacy endpoint resolver, several event handlers
-            # modify endpoint and request context.
-            self._register_eventbridge_events(
-                service_client, endpoint_bridge, endpoint_url
-            )
-
+        self._register_s3_events(
+            client=service_client,
+            endpoint_bridge=None,
+            endpoint_url=None,
+            client_config=client_config,
+            scoped_config=scoped_config,
+        )
+        self._register_s3_control_events(client=service_client)
         self._register_endpoint_discovery(
             service_client, endpoint_url, client_config
         )
@@ -358,7 +367,14 @@ class ClientCreator:
             endpoint_url=endpoint_url,
         ).register(client.meta.events)
 
-    def _register_s3_events(self, client, client_config, scoped_config):
+    def _register_s3_events(
+        self,
+        client,
+        endpoint_bridge,
+        endpoint_url,
+        client_config,
+        scoped_config,
+    ):
         if client.meta.service_model.service_name != 's3':
             return
         S3RegionRedirectorv2(None, client).register()
@@ -366,7 +382,14 @@ class ClientCreator:
             client.meta, client_config, scoped_config
         )
 
-    def _register_s3_control_events(self, client):
+    def _register_s3_control_events(
+        self,
+        client,
+        endpoint_bridge=None,
+        endpoint_url=None,
+        client_config=None,
+        scoped_config=None,
+    ):
         if client.meta.service_model.service_name != 's3control':
             return
         S3ControlArnParamHandlerv2().register(client.meta.events)
@@ -544,6 +567,7 @@ class ClientEndpointBridge:
         default_endpoint=None,
         service_signing_name=None,
         config_store=None,
+        service_signature_version=None,
     ):
         self.service_signing_name = service_signing_name
         self.endpoint_resolver = endpoint_resolver
@@ -551,6 +575,7 @@ class ClientEndpointBridge:
         self.client_config = client_config
         self.default_endpoint = default_endpoint or self.DEFAULT_ENDPOINT
         self.config_store = config_store
+        self.service_signature_version = service_signature_version
 
     def resolve(
         self, service_name, region_name=None, endpoint_url=None, is_secure=True
@@ -608,27 +633,10 @@ class ClientEndpointBridge:
             resolved, region_name, endpoint_url
         )
         if endpoint_url is None:
-            sslCommonName = resolved.get('sslCommonName')
-            hostname = resolved.get('hostname')
-            is_disabled = ensure_boolean(
-                os.environ.get('BOTO_DISABLE_COMMONNAME', False)
-            )
-            if (
-                not is_disabled
-                and sslCommonName is not None
-                and sslCommonName != hostname
-            ):
-                warnings.warn(
-                    f'The {service_name} client is currently using a '
-                    f'deprecated endpoint: {sslCommonName}. In the next '
-                    f'minor version this will be moved to {hostname}. '
-                    'See https://github.com/boto/botocore/issues/2705 '
-                    'for more details.',
-                    category=FutureWarning,
-                )
-                hostname = sslCommonName
             endpoint_url = self._make_url(
-                hostname, is_secure, resolved.get('protocols', [])
+                resolved.get('hostname'),
+                is_secure,
+                resolved.get('protocols', []),
             )
         signature_version = self._resolve_signature_version(
             service_name, resolved
@@ -784,9 +792,18 @@ class ClientEndpointBridge:
         if configured_version is not None:
             return configured_version
 
+        potential_versions = resolved.get('signatureVersions', [])
+        if (
+            self.service_signature_version is not None
+            and self.service_signature_version
+            not in _LEGACY_SIGNATURE_VERSIONS
+        ):
+            # Prefer the service model as most specific
+            # source of truth for new signature versions.
+            potential_versions = [self.service_signature_version]
+
         # Pick a signature version from the endpoint metadata if present.
         if 'signatureVersions' in resolved:
-            potential_versions = resolved['signatureVersions']
             if service_name == 's3':
                 return 's3v4'
             if 'v4' in potential_versions:
@@ -797,7 +814,7 @@ class ClientEndpointBridge:
                 if known in AUTH_TYPE_MAPS:
                     return known
         raise UnknownSignatureVersionError(
-            signature_version=resolved.get('signatureVersions')
+            signature_version=potential_versions
         )
 
 
